@@ -17,7 +17,8 @@ BUILDDIR="$(pwd)/build/tcl${TCLVERS}"
 OUTDIR="$(pwd)/out"
 INSTDIR="$(pwd)/inst"
 PATCHSCRIPTDIR="$(pwd)/patchscripts"
-export SRC SRCURL BUILDDIR OUTDIR INSTDIR PATCHSCRIPTDIR
+PATCHDIR="$(pwd)/patches"
+export SRC SRCURL BUILDDIR OUTDIR INSTDIR PATCHSCRIPTDIR PATCHDIR
 
 rm -rf 'build' 'out' 'inst'
 mkdir 'build' 'out' 'inst' || exit 1
@@ -56,14 +57,39 @@ fi
 
 	cd "${BUILDDIR}" || exit 1
 
+	# Apply patches if needed
+	for patch in "${PATCHDIR}/all"/tcl-${TCLVERS}-*.diff "${PATCHDIR}/${TCLVERS}"/tcl-${TCLVERS}-*.diff; do
+		if [ ! -f "${patch}" ]; then
+			continue
+		fi
+                
+		echo "Applying: ${patch}"
+		${PATCH:-patch} -p1 < "${patch}"
+	done
+
+
 	# Apply patch scripts if needed
 	for patchscript in "${PATCHSCRIPTDIR}"/*.sh; do
 		if [ -f "${patchscript}" ]; then
 			echo "Running patch script: ${patchscript}"
-			. "${patchscript}"
+
+			(
+				. "${patchscript}"
+			)
 		fi
 	done
 
+	# Patch Win32 builds to always provide DllMain if we are building KitDLL
+	if [ "${KITTARGET}" = "kitdll" ]; then
+		## DllMain is needed when building KitDLL
+		for filetopatch in win/tclWin32Dll.c win/tclWinInit.c; do
+			echo "Undefining STATIC_BUILD in \"${filetopatch}\""
+
+			sed 's@STATIC_BUILD@NEVER_STATIC_BUILD@g' "${filetopatch}" > "${filetopatch}.new" && cat "${filetopatch}.new" > "${filetopatch}"
+			rm -f "${filetopatch}.new"
+		done
+	fi
+
 	for dir in unix win macosx __fail__; do
 		if [ "${dir}" = "__fail__" ]; then
 			# If we haven't figured out how to build it, reject.
